@@ -24,6 +24,16 @@ class Document:
     '''
 
     def __init__(self, settings_path=None, styles=[]) -> None:
+        '''
+        Initialize a new document object.
+
+        Parameters:
+        settings_path (str): not really required ATM
+        styles (list(str)): list of paths to style sheets.
+
+        Returns:
+        None
+        '''
         self.Writer = Writer(settings_path, styles)
         self.Pages = []
         self.crop = False
@@ -31,22 +41,56 @@ class Document:
         self.height = 896
         self.margin = Margin()
 
-    def clear(self):
+    def clear(self) -> None:
+        '''
+        Clear the document object of all pages.
+        
+        Parameters:
+        None
+
+        Returns:
+        None
+        '''
         self.Pages = []
 
     def createPage(self) -> Page:
+        '''
+        Create a new page in the drawing and add it to the end of the page list.
+
+        Parameters:
+
+        Returns:
+        (Page): Page object
+        '''
         page = Page()
         self.Pages.append(page)
 
         return page
 
     def copyPage(self, page : Page) -> Page:
+        '''
+        Copy a given page and return a new page with the same structure. Add the new page to the list of pages.
+
+        Parameters:
+        page (Page): The page to be copied.
+
+        Returns:
+        (Page): The newly created page
+        '''
         newPage = page.copyA()
         self.Pages.append(newPage)
 
         return newPage
 
-    def getSize(self) -> Tuple[int, int]:
+    def getSize(self) -> Tuple[Tuple[int, int]]:
+        '''
+        Get the rectangular bounding box of all elements in the document.
+
+        Parameters:
+
+        Returns:
+        ((int,int), (int,int)): Returns a tuple of points (x_min,y_min),(x_max,y_max) that represents the bounding box of the drawing
+        '''
         minX = sys.maxsize
         maxX = -sys.maxsize - 1
         minY = sys.maxsize
@@ -72,8 +116,16 @@ class Document:
         else:
             return ((0, self.width), (0, self.height))
 
-    def write(self, path):
+    def write(self, path) -> None:
+        '''
+        Create the drawing and write it to the disk.
 
+        Parameters:
+        path (str): path where the created ipe drawing is saved to.
+        
+        Returns:
+        None
+        '''
         pages = []
         size = self.getSize()
 
