@@ -6,4 +6,6 @@ from .spline import Spline, SplineType
 from .splinegon import Splinegon
 from .group import Group
 from .glyph import Glyph
-from .circle import Circle
\ No newline at end of file
+from .circle import Circle
+from .label import Label
+from .minipage import Minipage
\ No newline at end of file
